==> huaweicloudsdkdas-3.1.120-py2.py3-none-any.whl: huaweicloudsdkdas/v3/model/create_health_report_task_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateHealthReportTaskResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'create_success': 'bool'
    }

    attribute_map = {
        'create_success': 'create_success'
    }

    def __init__(self, create_success=None):
        """CreateHealthReportTaskResponse

        The model defined in huaweicloud sdk

        :param create_success: 诊断任务创建是否成功
        :type create_success: bool
        """
        
        super(CreateHealthReportTaskResponse, self).__init__()

        self._create_success = None
        self.discriminator = None

        if create_success is not None:
            self.create_success = create_success

    @property
    def create_success(self):
        """Gets the create_success of this CreateHealthReportTaskResponse.

        诊断任务创建是否成功

        :return: The create_success of this CreateHealthReportTaskResponse.
        :rtype: bool
        """
        return self._create_success

    @create_success.setter
    def create_success(self, create_success):
        """Sets the create_success of this CreateHealthReportTaskResponse.

        诊断任务创建是否成功

        :param create_success: The create_success of this CreateHealthReportTaskResponse.
        :type create_success: bool
        """
        self._create_success = create_success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateHealthReportTaskResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdas-3.1.150-py2.py3-none-any.whl: huaweicloudsdkdas/v3/model/create_health_report_task_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateHealthReportTaskResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'create_success': 'bool'
    }

    attribute_map = {
        'create_success': 'create_success'
    }

    def __init__(self, create_success=None):
        r"""CreateHealthReportTaskResponse

        The model defined in huaweicloud sdk

        :param create_success: 诊断任务创建是否成功
        :type create_success: bool
        """
        
        super(CreateHealthReportTaskResponse, self).__init__()

        self._create_success = None
        self.discriminator = None

        if create_success is not None:
            self.create_success = create_success

    @property
    def create_success(self):
        r"""Gets the create_success of this CreateHealthReportTaskResponse.

        诊断任务创建是否成功

        :return: The create_success of this CreateHealthReportTaskResponse.
        :rtype: bool
        """
        return self._create_success

    @create_success.setter
    def create_success(self, create_success):
        r"""Sets the create_success of this CreateHealthReportTaskResponse.

        诊断任务创建是否成功

        :param create_success: The create_success of this CreateHealthReportTaskResponse.
        :type create_success: bool
        """
        self._create_success = create_success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateHealthReportTaskResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
